@@ -2,18 +2,18 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-import os, sys, syst3m ; sys.path.insert(1, syst3m.defaults.source_path(__file__, back=2))
-os.environ["CLI"] = "True"
+from dev0s import * ; Defaults.insert(Defaults.source_path(__file__, back=2))
+Environment["CLI"] = True
 os.environ["INTERACTIVE"] = "True"
 from ssht00ls.classes.config import *
 import ssht00ls
 
 # the cli object class.
-class CLI(cl1.CLI):
+class CLI_(CLI.CLI):
 	def __init__(self):
 		
 		# defaults.
-		cl1.CLI.__init__(self,
+		CLI.CLI.__init__(self,
 			modes={
 				"Keys:":"*chapter*",
 				"    --generate":"Generate a ssh key.",
@@ -91,7 +91,6 @@ class CLI(cl1.CLI):
 				#"    --list-daemons":"List all daemons & their status.",
 				"Agent:":"*chapter*",
 				"    --sync":"Manually synchronize the aliases & add the keys to the agent.",
-				"    --start-agent":"Start the ssht00ls agent manually.",
 				"    --stop-agent":"Stop the ssht00ls agent.",
 				"Basic:":"*chapter*",
 				"    --kill <identifier>":"Kill all ssh processes that include the identifier.",
@@ -120,10 +119,10 @@ class CLI(cl1.CLI):
 	def start(self):
 		
 		# check arguments.
-		self.arguments.check(json=syst3m.defaults.options.json, exceptions=["--log-level", "--version", "--create-alias", "--non-interative"])
+		self.arguments.check(json=Defaults.options.json, exceptions=["--log-level", "--version", "--create-alias", "--non-interative"])
 
 		# sync aliases.
-		if encryption.activated and not self.arguments.present(["-h", "--config", "--help", "--version", "--unmount", "--list-tunnels"]):
+		if ssht00ls_agent.activated and not self.arguments.present(["-h", "--config", "--help", "--version", "--unmount", "--list-tunnels"]):
 			str_args = Array(sys.argv).string(joiner=" ")
 			aliases = ["*"]
 			if not self.arguments.present(["--sync"]):
@@ -134,7 +133,7 @@ class CLI(cl1.CLI):
 			response = ssht00ls.aliases.sync(aliases=aliases)
 			if self.arguments.present("--sync"):
 				self.stop(response=response)
-			if not response["success"]: response.crash(json=syst3m.defaults.options.json)
+			if not response["success"]: response.crash(json=Defaults.options.json)
 
 		#
 		# BASICS
@@ -142,11 +141,11 @@ class CLI(cl1.CLI):
 
 		# version.
 		if self.arguments.present(['--version']):
-			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version.py").replace("\n",""), json=syst3m.defaults.options.json)
+			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version.py").replace("\n",""), json=Defaults.options.json)
 
 		# config.
 		elif self.arguments.present('--config'):
-			if syst3m.defaults.options.json:
+			if Defaults.options.json:
 				print(CONFIG.dictionary)
 			else:
 				os.system(f"nano {CONFIG.file_path.path}")
@@ -156,16 +155,16 @@ class CLI(cl1.CLI):
 			response = ssht00ls.ssh.utils.kill(
 				identifier=self.arguments.get("--kill"), 
 				sudo=self.arguments.present("--sudo"),)
-			self.stop(response=response, json=syst3m.defaults.options.json)
+			self.stop(response=response, json=Defaults.options.json)
 
 		# reset cache.
 		elif self.arguments.present('--reset-cache'):
 			path = cache.path
 			os.system(f"rm -fr {path}")
 			if Files.exists(path):
-				self.stop(error=f"Failed to reset cache {path}.", json=syst3m.defaults.options.json)
+				self.stop(error=f"Failed to reset cache {path}.", json=Defaults.options.json)
 			else:
-				self.stop(message=f"Successfully resetted cache {path}.", json=syst3m.defaults.options.json)
+				self.stop(message=f"Successfully resetted cache {path}.", json=Defaults.options.json)
 
 
 		#
@@ -186,7 +185,7 @@ class CLI(cl1.CLI):
 			response = ssht00ls.ssh.command(
 				alias=alias,
 				command=command,
-				serialize=syst3m.defaults.options.json,)
+				serialize=Defaults.options.json,)
 			if not response.success:
 				self.stop(response=response)
 			else:
@@ -199,7 +198,7 @@ class CLI(cl1.CLI):
 		# list aliases.
 		elif self.arguments.present("--list-aliases"):
 			response = ssht00ls.aliases.list()
-			if syst3m.defaults.options.json:
+			if Defaults.options.json:
 				print(response.dictionary)
 			else:
 				if self.arguments.present("--joiner"):
@@ -213,7 +212,7 @@ class CLI(cl1.CLI):
 
 			# help.
 			if self.arguments.present(['-h', '--help']):
-				self.docs(chapter="aliases", success=True, json=syst3m.defaults.options.json)
+				self.docs(chapter="aliases", success=True, json=Defaults.options.json)
 
 			# get alias.
 			aliases = self.arguments.get("--alias")
@@ -234,17 +233,17 @@ class CLI(cl1.CLI):
 
 				# show info.
 				if self.arguments.present('--info'):
-					if syst3m.defaults.options.json:
+					if Defaults.options.json:
 						info[alias] = {alias:alias_info}
 					else:
 						print(self.__str_representable__({alias:alias_info}, start_indent=0))
 
 				# delete.
 				elif self.arguments.present('--delete'):
-					if not self.arguments.present(["-f", "--forced"]) and not syst3m.console.input(f"You are deleting alias [{alias}]. Do you wish to proceed?", yes_no=True):
+					if not self.arguments.present(["-f", "--forced"]) and not Console.input(f"You are deleting alias [{alias}]. Do you wish to proceed?", yes_no=True):
 						self.stop(error="Aborted.")
 					response = ssht00ls.aliases.delete(alias=alias)
-					self.stop(response=response, json=syst3m.defaults.options.json)
+					self.stop(response=response, json=Defaults.options.json)
 
 				# set passphrase.
 				elif self.arguments.present('--delete'):
@@ -261,7 +260,7 @@ class CLI(cl1.CLI):
 						"passphrase":passphrase,
 						"pin":pin,
 					})
-					self.stop(response=response, json=syst3m.defaults.options.json)
+					self.stop(response=response, json=Defaults.options.json)
 
 				# edit config.
 				elif self.arguments.present('--edit'):
@@ -275,9 +274,9 @@ class CLI(cl1.CLI):
 							utils.save_config_safely()
 						except: success = False
 						if success:
-							self.stop(message=f"Successfully renamed alias {alias} to {new_alias}.", json=syst3m.defaults.options.json)
+							self.stop(message=f"Successfully renamed alias {alias} to {new_alias}.", json=Defaults.options.json)
 						else:
-							self.stop(error=f"Failed to rename alias {alias} to {new_alias}.", json=syst3m.defaults.options.json)
+							self.stop(error=f"Failed to rename alias {alias} to {new_alias}.", json=Defaults.options.json)
 
 					# edit alias config.
 					else:
@@ -303,7 +302,7 @@ class CLI(cl1.CLI):
 							value_exceptions=[None],
 							# save the edits.
 							save=True,)
-						self.stop(response=response, json=syst3m.defaults.options.json)
+						self.stop(response=response, json=Defaults.options.json)
 
 				# create.
 				elif self.arguments.present('--create'):
@@ -355,13 +354,13 @@ class CLI(cl1.CLI):
 							pin=self.arguments.get('--pin', required=False, default=None, chapter="aliases", mode="--create-alias"), )
 
 					# log to console.
-					self.stop(response=response, json=syst3m.defaults.options.json)
+					self.stop(response=response, json=Defaults.options.json)
 
 				# invalid.
-				else: self.invalid(chapter="aliases", json=syst3m.defaults.options.json)
+				else: self.invalid(chapter="aliases", json=Defaults.options.json)
 
 			# json show info joined.
-			if syst3m.defaults.options.json and self.arguments.present('--info'):
+			if Defaults.options.json and self.arguments.present('--info'):
 				print(info)
 
 		#
@@ -378,7 +377,7 @@ class CLI(cl1.CLI):
 				path=self.arguments.get("--path", chapter="keys", mode="--generate"), 
 				passphrase=passphrase, 
 				comment=self.arguments.get("--comment", chapter="keys", mode="--generate"),)
-			self.stop(response=response, json=syst3m.defaults.options.json)
+			self.stop(response=response, json=Defaults.options.json)
 
 		#
 		# PULL & PUSH
@@ -396,10 +395,10 @@ class CLI(cl1.CLI):
 					notes={
 						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 					},
-					json=syst3m.defaults.options.json,)
+					json=Defaults.options.json,)
 			alias,remote = remote.split(":")
-			remote = syst3m.env.fill(remote)
-			path = syst3m.env.fill(path)
+			remote = Environment.fill(remote)
+			path = Environment.fill(path)
 			exclude = []
 			if self.arguments.present("--exclude"): 
 				exclude = self.arguments.get("--exclude", chapter="push & pull", mode="--pull", format=list)
@@ -413,7 +412,7 @@ class CLI(cl1.CLI):
 				delete=self.arguments.present("--delete"), 
 				safe=self.arguments.present("--safe"), 
 				directory=True, )
-			self.stop(response=response, json=syst3m.defaults.options.json)
+			self.stop(response=response, json=Defaults.options.json)
 
 		# push.
 		elif self.arguments.present('--push'):
@@ -427,10 +426,10 @@ class CLI(cl1.CLI):
 					notes={
 						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 					},
-					json=syst3m.defaults.options.json,)
+					json=Defaults.options.json,)
 			alias,remote = remote.split(":")
-			remote = syst3m.env.fill(remote)
-			path = syst3m.env.fill(path)
+			remote = Environment.fill(remote)
+			path = Environment.fill(path)
 			exclude = []
 			if self.arguments.present("--exclude"): 
 				exclude = self.arguments.get("--exclude", chapter="push & pull", mode="--pull", format=list)
@@ -444,7 +443,7 @@ class CLI(cl1.CLI):
 				delete=self.arguments.present("--delete"), 
 				safe=self.arguments.present("--safe"), 
 				directory=None, )
-			self.stop(response=response, json=syst3m.defaults.options.json)
+			self.stop(response=response, json=Defaults.options.json)
 
 		#
 		# MOUNTS
@@ -463,10 +462,10 @@ class CLI(cl1.CLI):
 						notes={
 							"<alias>:<remote>":"Pack the alias & remote as a tuple together as one argument in the following format [<alias>:<remote>]."
 						},
-						json=syst3m.defaults.options.json,)
+						json=Defaults.options.json,)
 				alias,remote = remote.split(":")
-				remote = syst3m.env.fill(remote)
-				path = syst3m.env.fill(path)
+				remote = Environment.fill(remote)
+				path = Environment.fill(path)
 				response = ssht00ls.sshfs.mount(
 					alias=alias, 
 					remote=remote, 
@@ -483,9 +482,9 @@ class CLI(cl1.CLI):
 						notes={
 							"<alias>:<id>":"Pack the alias & share id as a tuple together as one argument in the following format [<alias>:<id>]."
 						},
-						json=syst3m.defaults.options.json,)
+						json=Defaults.options.json,)
 				alias,id = alias.split(":")
-				path = syst3m.env.fill(path)
+				path = Environment.fill(path)
 				response = ssht00ls.smb.mount(
 					id=id, 
 					path=path,
@@ -497,7 +496,7 @@ class CLI(cl1.CLI):
 					tunnel=self.arguments.present("--tunnel"), 
 					reconnect=self.arguments.present("--reconnect"), 
 				)
-			self.stop(response=response, json=syst3m.defaults.options.json)
+			self.stop(response=response, json=Defaults.options.json)
 
 		# unmount.
 		elif self.arguments.present('--unmount'):
@@ -506,7 +505,7 @@ class CLI(cl1.CLI):
 				path=path,
 				forced=self.arguments.present("--forced"), 
 				sudo=self.arguments.present("--sudo"), )
-			self.stop(response=response, json=syst3m.defaults.options.json)
+			self.stop(response=response, json=Defaults.options.json)
 
 		#
 		# SSYNC
@@ -517,12 +516,12 @@ class CLI(cl1.CLI):
 			index = self.arguments.get("--index", chapter="ssync", mode="--index")
 			if ":" in index:
 				alias,remote = index.split(":")
-				remote = syst3m.env.fill(remote)
+				remote = Environment.fill(remote)
 				response = ssht00ls.ssync.index(path=remote, alias=alias)
 			else:
-				index = syst3m.env.fill(index)
+				index = Environment.fill(index)
 				response = ssht00ls.ssync.index(path=index)
-			self.stop(response=response, json=syst3m.defaults.options.json)
+			self.stop(response=response, json=Defaults.options.json)
 
 		# sync
 			"""
@@ -538,17 +537,17 @@ class CLI(cl1.CLI):
 						notes={
 							"<alias>:<remote>":"Pack the alias & remote as a tuple together as one argument in the following format [<alias>:<remote>]."
 						},
-						json=syst3m.defaults.options.json,)
+						json=Defaults.options.json,)
 				alias,remote = remote.split(":")
-				remote = syst3m.env.fill(remote)
-				path = syst3m.env.fill(path)
+				remote = Environment.fill(remote)
+				path = Environment.fill(path)
 				response = ssht00ls.ssync.mount(
 					alias=alias, 
 					remote=remote, 
 					path=path,
 					forced=self.arguments.present("--forced"), 
 					mode="sync",)
-				self.stop(response=response, json=syst3m.defaults.options.json)
+				self.stop(response=response, json=Defaults.options.json)
 			"""
 
 		#
@@ -558,7 +557,7 @@ class CLI(cl1.CLI):
 		# list tunnels.
 		elif self.arguments.present("--list-tunnels"):
 			response = ssht00ls.ssh.tunnel.list(alias=self.arguments.get("--list-tunnels", required=False, default=None))
-			if syst3m.defaults.options.json:
+			if Defaults.options.json:
 				print(response.dictionary)
 			else:
 				if self.arguments.present("--joiner"):
@@ -572,7 +571,7 @@ class CLI(cl1.CLI):
 
 			# help.
 			if self.arguments.present(['-h', '--help']):
-				self.docs(chapter="tunnels", success=True, json=syst3m.defaults.options.json)
+				self.docs(chapter="tunnels", success=True, json=Defaults.options.json)
 
 			# tunnel.
 			id = self.arguments.get("--tunnel", index=1, chapter="tunnels", notes={})
@@ -587,7 +586,7 @@ class CLI(cl1.CLI):
 					notes={
 						"<port>:<ip>:<remote_port>:<alias>":"Pack the port, ip, remote port & alias as a tuple together as one argument in the following format [<port>:<ip>:<remote_port>:<alias>]."
 					},
-					json=syst3m.defaults.options.json,)
+					json=Defaults.options.json,)
 			tunnel = ssht00ls.ssh.Tunnel(
 				alias=alias,
 				ip=ip,
@@ -596,7 +595,7 @@ class CLI(cl1.CLI):
 				reconnect=self.arguments.present("--reconnect"),
 				sleeptime=self.arguments.get("--sleeptime", required=False, default=60, format=int),
 				reattemps=self.arguments.get("--reattemps", required=False, default=15, format=int),
-				log_level=syst3m.defaults.options.log_level,)
+				log_level=Defaults.options.log_level,)
 
 			# establish.
 			if self.arguments.present("--establish"):
@@ -627,12 +626,12 @@ class CLI(cl1.CLI):
 						notes={
 							"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
 						},
-						json=syst3m.defaults.options.json,)
+						json=Defaults.options.json,)
 				alias,remote = remote.split(":")
-				remote = syst3m.env.fill(remote)
-				path = syst3m.env.fill(path)
+				remote = Environment.fill(remote)
+				path = Environment.fill(path)
 				response = ssht00ls.ssync.daemon(alias=alias, remote=remote, path=path)
-				self.stop(response=response, json=syst3m.defaults.options.json)
+				self.stop(response=response, json=Defaults.options.json)
 
 			# stop daemon.
 			elif self.arguments.present('--stop-daemon'):
@@ -640,23 +639,23 @@ class CLI(cl1.CLI):
 				for path in self.arguments.get("--stop-daemon", index=1, chapter="daemon", mode="--stop-daemon", format=list):
 					response = ssht00ls.ssync.daemons.stop(path)
 					if not response["success"]:
-						self.stop(response=response, json=syst3m.defaults.options.json)
+						self.stop(response=response, json=Defaults.options.json)
 						c += 1
 				if c > 0:
-					self.stop(message=f"Successfully stopped {c} daemon(s).", json=syst3m.defaults.options.json)
+					self.stop(message=f"Successfully stopped {c} daemon(s).", json=Defaults.options.json)
 				else:
-					self.stop(error="No daemons found.", json=syst3m.defaults.options.json)
+					self.stop(error="No daemons found.", json=Defaults.options.json)
 
 			# list daemons.
 			elif self.arguments.present('--list-daemons'):
 				
 				daemons = ssht00ls.ssync.daemons.status()
 				if len(daemons) == 0:
-					self.stop(message=f"There are no active daemons.", json=syst3m.defaults.options.json)
+					self.stop(message=f"There are no active daemons.", json=Defaults.options.json)
 				print("Daemons:")
 				for path, status in daemons.items():
 					print(f" * {path}: {status}")
-				self.stop(message=f"Successfully listed {len(daemons)} daemon(s).", json=syst3m.defaults.options.json)
+				self.stop(message=f"Successfully listed {len(daemons)} daemon(s).", json=Defaults.options.json)
 			"""
 
 		# 
@@ -665,7 +664,7 @@ class CLI(cl1.CLI):
 
 		# help.
 		elif self.arguments.present(['-h', '--help']):
-			self.docs(success=True, json=syst3m.defaults.options.json)
+			self.docs(success=True, json=Defaults.options.json)
 
 		# invalid.
 		else: self.invalid()
@@ -678,7 +677,7 @@ class CLI(cl1.CLI):
 
 # main.
 if __name__ == "__main__":
-	cli = CLI()
+	cli = CLI_()
 	cli.start()
 
 
