@@ -4,7 +4,7 @@
 # imports.
 # keep this import style so you can also use the keys.Keys() etc directly.
 import syst3m
-from ssht00ls.classes.config import encryption
+from ssht00ls.classes.config import ssht00ls_agent
 from ssht00ls.classes.config import NETWORK_INFO as network_info
 
 # import classes.
