@@ -3,8 +3,7 @@
 
 # imports.
 import os
-from fil3s import *
-from r3sponse import r3sponse
+from dev0s import *
 from ssht00ls.classes.config import * 
 from ssht00ls.classes.ssh import ssh
 from ssht00ls.classes.ssync.index import index
@@ -32,14 +31,13 @@ def serialize_path(path, append_last_slash=False):
 # get the size of a dir.
 def size(path, alias=None, log_level=0):
 	if alias == None:
-		return r3sponse.success(f"Successfully retrieved the size of {path}.", {
+		return Response.success(f"Successfully retrieved the size of {path}.", {
 			"size":FilePath(path).size(mode="MB"),
 		})
 	else:
 		return execute(
-			command=f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ' python3 /usr/local/lib/ssht00ls/classes/utils/size.py {path} ' '""",
-			message=f"Successfully retrieved the size of {alias}:{path}.",
-			error=f"Failed to retrieve the size of {alias}:{path}.",
+			command=f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ' python3 /usr/local/lib/ssht00ls/classes/utils/size.py {path} --non-interactive ' '""",
+			message=f"Successfully retrieved the size of [{alias}:{path}].",
 			log_level=log_level,
 			serialize=True,)
 
@@ -69,7 +67,7 @@ def pull(
 	# checks.
 	checks=True,
 	# log level.
-	log_level=syst3m.defaults.options.log_level,
+	log_level=Defaults.options.log_level,
 	# get the command in str.
 	command=False,
 ):	
@@ -85,14 +83,14 @@ def pull(
 		#if not response.success: return response
 		
 		# check encryption activated.
-		#if not encryption.activated:
-		#	return r3sponse.error("The encryption requires to be activated.")
+		#if not ssht00ls_agent.activated:
+		#	return Response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
 
 		# check passphrase.
 		#if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
-		#	response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+		#	response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 		#else:
-		#	response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+		#	response = ssht00ls_agent.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
 		#if not response.success: return response
 		#passphrase = response.decrypted.decode()
 		
@@ -122,7 +120,7 @@ def pull(
 	if not Files.exists(base): 
 		os.system(f"mkdir -p {base}")
 		if not Files.exists(base): 
-			return r3sponse.error(f"Failed to create pull base {base}.")
+			return Response.error(f"Failed to create pull base {base}.")
 		if log_level >= 3:
 			print(f"Created directory {base}.")
 
@@ -144,9 +142,8 @@ def pull(
 	else:
 		return execute(
 			command=_command_,
-			message=f"Successfully pulled [{alias}:{remote}] to [{path}].",
-			error=f"Failed to pull [{alias}:{remote}] to [{path}].",
 			loader=f"Pulling [{alias}:{remote}] to [{path}]",
+			message=f"Successfully pulled [{alias}:{remote}] to [{path}].",
 			log_level=log_level,
 		)
 
@@ -179,7 +176,7 @@ def push(
 	checks=True,
 	check_base=True,
 	# log level.
-	log_level=syst3m.defaults.options.log_level,
+	log_level=Defaults.options.log_level,
 	# get the command in str.
 	command=False,
 ):
@@ -195,8 +192,8 @@ def push(
 		#if not response.success: return response
 		
 		# check encryption activated.
-		#if not encryption.activated:
-		#	return r3sponse.error("The encryption requires to be activated.")
+		#if not ssht00ls_agent.activated:
+		#	return Response.error(f"The {ssht00ls_agent.id} encryption requires to be activated.")
 		
 		# check passphrase.
 		#if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
@@ -217,7 +214,7 @@ def push(
 		# dir.
 		if directory == None: directory = os.path.isdir(path)
 		elif directory and not os.path.isdir(path):
-			return r3sponse.error(f"Path {path} is not a directory.")
+			return Response.error(f"Path {path} is not a directory.")
 
 	# check remote base.
 	# must be excluded from the checks == False.
@@ -241,9 +238,8 @@ def push(
 	else:
 		return execute(
 			command=_command_,
-			message=f"Successfully pushed [{path}] to [{alias}:{remote}].",
-			error=f"Failed to push [{path}] to [{alias}:{remote}].",
 			loader=f"Pushing [{path}] to [{alias}:{remote}].",
+			message=f"Successfully pushed [{path}] to [{alias}:{remote}].",
 			log_level=log_level,
 		)
 
