@@ -3,5 +3,5 @@
 try: import syst3m
 except: os.system("pip3 install syst3m")
 import os, sys, syst3m
-for i in sys.argv: print(syst3m.color.fill(i))
+for i in sys.argv: print(color.fill(i))
 sys.exit(1)
\ No newline at end of file
